@@ -30,28 +30,44 @@ describe 'cinder::backend::rbd' do
         is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rbd_user").with_value(req_params[:rbd_user])
         is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rbd_secret_uuid").with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/backend_host").with_value('rbd:'"#{req_params[:rbd_pool]}")
+        is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/backend_availability_zone").with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/reserved_percentage").with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/max_over_subscription_ratio").with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rados_connect_timeout").with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rados_connection_interval").with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rados_connection_retries").with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rbd_store_chunk_size").with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rbd_cluster_name").with_value('ceph')
         is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/report_dynamic_total_capacity").with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rbd_exclusive_cinder_pool").with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/enable_deferred_deletion").with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/deferred_deletion_delay").with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/deferred_deletion_purge_interval").with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rbd_concurrent_flatten_operations").with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/report_discard_supported").with_value(true)
       }
 
       context 'with parameters' do
         let :params do
           req_params.merge!({
-            :rbd_ceph_conf                    => '/opt/ceph.conf',
-            :rbd_flatten_volume_from_snapshot => true,
-            :rbd_secret_uuid                  => 'b129523a-61a5-4653-86d1-2b055f970801',
-            :rbd_max_clone_depth              => 5,
-            :rados_connect_timeout            => 10,
-            :rados_connection_interval        => 5,
-            :rados_connection_retries         => 3,
-            :rbd_store_chunk_size             => 4,
-            :report_dynamic_total_capacity    => true,
-            :rbd_exclusive_cinder_pool        => false,
+            :backend_host                      => 'test_host.fqdn.com',
+            :backend_availability_zone         => 'my_zone',
+            :reserved_percentage               => 10,
+            :max_over_subscription_ratio       => 1.5,
+            :rbd_ceph_conf                     => '/opt/ceph.conf',
+            :rbd_flatten_volume_from_snapshot  => true,
+            :rbd_secret_uuid                   => 'b129523a-61a5-4653-86d1-2b055f970801',
+            :rbd_max_clone_depth               => 5,
+            :rados_connect_timeout             => 10,
+            :rados_connection_interval         => 5,
+            :rados_connection_retries          => 3,
+            :rbd_store_chunk_size              => 4,
+            :report_dynamic_total_capacity     => true,
+            :rbd_exclusive_cinder_pool         => false,
+            :enable_deferred_deletion          => false,
+            :deferred_deletion_delay           => 0,
+            :deferred_deletion_purge_interval  => 60,
+            :rbd_concurrent_flatten_operations => 3,
           })
         end
 
@@ -65,13 +81,20 @@ describe 'cinder::backend::rbd' do
           is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rbd_pool").with_value(req_params[:rbd_pool])
           is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rbd_user").with_value(req_params[:rbd_user])
           is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rbd_secret_uuid").with_value(params[:rbd_secret_uuid])
-          is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/backend_host").with_value('rbd:'"#{req_params[:rbd_pool]}")
+          is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/backend_host").with_value('test_host.fqdn.com')
+          is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/backend_availability_zone").with_value('my_zone')
+          is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/reserved_percentage").with_value(10)
+          is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/max_over_subscription_ratio").with_value(1.5)
           is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rados_connect_timeout").with_value(params[:rados_connect_timeout])
           is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rados_connection_interval").with_value(params[:rados_connection_interval])
           is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rados_connection_retries").with_value(params[:rados_connection_retries])
           is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rbd_store_chunk_size").with_value(params[:rbd_store_chunk_size])
           is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/report_dynamic_total_capacity").with_value(params[:report_dynamic_total_capacity])
           is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rbd_exclusive_cinder_pool").with_value(params[:rbd_exclusive_cinder_pool])
+          is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/enable_deferred_deletion").with_value(params[:enable_deferred_deletion])
+          is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/deferred_deletion_delay").with_value(params[:deferred_deletion_delay])
+          is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/deferred_deletion_purge_interval").with_value(params[:deferred_deletion_purge_interval])
+          is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/rbd_concurrent_flatten_operations").with_value(params[:rbd_concurrent_flatten_operations])
           is_expected.to contain_cinder_config("#{req_params[:volume_backend_name]}/report_discard_supported").with_value(true)
         }
       end
@@ -103,18 +126,6 @@ describe 'cinder::backend::rbd' do
         it { is_expected.to contain_cinder_config('rbd-ssd/param1').with_value('value1') }
       end
 
-      context 'override backend_host and backend_availability_zone parameters' do
-        before do
-          params.merge!({
-            :backend_host              => 'test_host.fqdn.com',
-            :backend_availability_zone => 'my_zone',
-          })
-        end
-
-        it { is_expected.to contain_cinder_config('rbd-ssd/backend_host').with_value('test_host.fqdn.com') }
-        it { is_expected.to contain_cinder_config('rbd-ssd/backend_availability_zone').with_value('my_zone') }
-      end
-
       context 'rbd backend with cinder type' do
         before do
           params.merge!( :manage_volume_type => true )
@@ -128,30 +139,6 @@ describe 'cinder::backend::rbd' do
     end
   end
 
-  shared_examples 'cinder::backend::rbd on Debian' do
-    it { is_expected.to contain_file('/etc/default/cinder-volume').with(
-      :ensure => 'present'
-    )}
-
-    it { is_expected.to contain_file_line('set initscript env rbd-ssd').with(
-      :line   => /CEPH_ARGS=\"--id test\"/,
-      :path   => '/etc/default/cinder-volume',
-      :notify => 'Anchor[cinder::service::begin]'
-    )}
-  end
-
-  shared_examples 'cinder::backend::rbd on RedHat' do
-    it { is_expected.to contain_file('/etc/sysconfig/openstack-cinder-volume').with(
-      :ensure => 'present'
-    )}
-
-    it { is_expected.to contain_file_line('set initscript env rbd-ssd').with(
-      :line   => /export CEPH_ARGS=\"--id test\"/,
-      :path   => '/etc/sysconfig/openstack-cinder-volume',
-      :notify => 'Anchor[cinder::service::begin]'
-    )}
-  end
-
   on_supported_os({
     :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
@@ -161,7 +148,6 @@ describe 'cinder::backend::rbd' do
       end
 
       it_behaves_like 'cinder::backend::rbd'
-      it_behaves_like "cinder::backend::rbd on #{facts[:os]['family']}"
     end
   end
 end
